from math import *
from euclid import *
from omega import *
from cyclops import *

scene = getSceneManager()

# deal with audio                                                                         
env = getSoundEnvironment()
s_sound = env.loadSoundFromFile("beep", "/menu_sounds/menu_select.wav")


# set the background to black
scene.setBackgroundColor(Color(0, 0, 0, 1))

# Create a directional light                                                                                    
light1 = Light.create()
light1.setLightType(LightType.Directional)
light1.setLightDirection(Vector3(-1.0, -1.0, -1.0))
light1.setColor(Color(0.7, 0.7, 0.7, 1.0))
light1.setAmbient(Color(0.5, 0.5, 0.5, 1.0))
light1.setEnabled(True)

# Load a static model
torusModel = ModelInfo()
torusModel.name = "torus"
#torusModel.path = "mapquestaerial.earth"
torusModel.path = "mapquestmap.earth"
scene.loadModel(torusModel)

# Create a scene object using the loaded model
torus = StaticObject.create("torus")
torus.getMaterial().setLit(False)
torus.pitch(radians(-70.0))

torus.setVisible(False)

# Load a static model
torusModel2 = ModelInfo()
torusModel2.name = "torus2"
torusModel2.path = "mapquestaerial.earth"
#torusModel2.path = "ready.earth"
scene.loadModel(torusModel2)

# Create a scene object using the loaded model
torus2 = StaticObject.create("torus2")
torus2.getMaterial().setLit(False)
torus2.pitch(radians(-70.0))



setNearFarZ(1, 20 * torus.getBoundRadius())

cam = getDefaultCamera()

# Setting the camera by hand. Should find a better way
# and give the user a better way to fly around the planet

# planet is centered at 0,0,0 with radius of 6356752.5 - earth is 6371 km
# so this is in cm?

#cam.setPosition(Vector3(313173.30, -4469345.79, 6507944.23))
cam.setPosition(Vector3(0, 0, 9000000))
#cam.roll(3.14159)

# set a fast speed for travel by default
cam.getController().setSpeed(300000)

# since the scale here is pretty large stereo doesnt help much
# so lets start with it turned off
toggleStereo()


# it would be better to set the speed based on the height over the surface
# to move slower as you get closer

d0 = 0
d1 = 0
d2 = 0
r = 0
r2 = 0

# set flight speed based on altitude

def onUpdate(frame, t, dt):
    d = cam.getPosition()
    d0 = float(d[0])
    d1 = float(d[1])
    d2 = float(d[2])
#    r = math.sqrt(d0*d0 + d1*d1 + d2*d2) - torus.getBoundRadius() # altitude in cm
    r = math.sqrt(d0*d0 + d1*d1 + d2*d2) - 6370000 # altitude in cm
    cam.getController().setSpeed(0.25 * r)

setUpdateFunction(onUpdate)


#handle events from the wand                                                              
# left and right buttons shift between the two maps                                       

def handleEvent():
    global userScaleFactor

    e = getEvent()
    if(e.isButtonDown(EventFlags.ButtonLeft)):
        print("Left button pressed")
        torus.setVisible(False)
        torus2.setVisible(True)

        #play button sound                                                                
        si_sound = SoundInstance(s_sound)
        si_sound.setPosition( e.getPosition() )
        si_sound.setVolume(1.0)
        si_sound.setWidth(20)
        si_sound.play()

    if(e.isButtonDown(EventFlags.ButtonRight)):
        print("Right button pressed")
        torus2.setVisible(False)
        torus.setVisible(True)

        #play button sound                                                                
        si_sound = SoundInstance(s_sound)
        si_sound.setPosition( e.getPosition() )
        si_sound.setVolume(1.0)
        si_sound.setWidth(20)
        si_sound.play()

# by default user can use the joystick to spin the world and fly                          
# but a better flying model should be added in                                            

setEventFunction(handleEvent)
